@@ -3,7 +3,7 @@ from itertools import combinations, combinations_with_replacement
 import numpy as np
 from ase.neighborlist import NeighborList
 
-from .cutoff import Cutoff
+from featurebox.featurizers.descriptors.cutoff import Cutoff
 
 
 class ACSF:
@@ -27,7 +27,7 @@ class ACSF:
     """
 
     def __init__(self, symmetry_parameters=None, Rc=6.5,
-                 derivative=True, stress=False, cutoff='cosine', atom_weighted=False):
+                 derivative=False, stress=False, cutoff='cosine', atom_weighted=False):
 
         if symmetry_parameters is None:
             symmetry_parameters = {'G2': {'eta': [0.1, 0.2, ], 'Rs': [0.0, 0.1]}}
@@ -1149,7 +1149,7 @@ if __name__ == '__main__':
         si.set_cell(cell)
         print(si.get_cell())
 
-        # bp = ACSF(symmetry, Rc=Rc, derivative=True, stress=True, atom_weighted=False)
+        # bp = ACSF(symmetry, Rc=Rc, derivative=False, stress=True, atom_weighted=False)
         # des = bp.calculate(si, system=[14])
 
         # print("G:", des['x'][0])
@@ -1159,7 +1159,7 @@ if __name__ == '__main__':
         # print("GPrime", des['dxdr'][0,:,4,:])
         # print(np.einsum('ijklm->klm', des['rdxdr']))
 
-        bp = ACSF(symmetry, Rc=Rc, derivative=True, stress=True, cutoff='cosine', atom_weighted=True)
+        bp = ACSF(symmetry, Rc=Rc, derivative=False, stress=True, cutoff='cosine', atom_weighted=True)
         des = bp.calculate(si, system=[14])
         print(des['x'].shape)
         print("G:", des['x'][0])
